@@ -740,7 +740,7 @@ submit -p @@file=globnat:indeck* sim.exe @@file
          self.parser.add_option("--venueStatus",action="callback",
                                                 callback=self.__grabMultipleStringArguments,dest="statusVenues",
                                                 callback_kwargs={'isOptional':True},
-                                                help="Report statsu for one or more venues.")
+                                                help="Report status for one or more venues.")
       else:
          self.parser.add_option("--status",action="callback",
                                            callback=self.__grabJobIdArgument,dest="statusIds",
@@ -814,7 +814,7 @@ submit -p @@file=globnat:indeck* sim.exe @@file
                                               callback_kwargs={'isOptional':False},
                                               help="Multiprocessor job manager")
       self.parser.add_option("-r","--redundancy",action="store",type="int",dest="nRedundant",
-                                                 help="Number of indentical simulations to execute in parallel")
+                                                 help="Number of identical simulations to execute in parallel")
       self.parser.set_defaults(metrics=False)
       self.parser.add_option("-M","--metrics",action="store_true",dest="metrics",
                                               help="Report resource usage on exit")
@@ -882,12 +882,19 @@ submit -p @@file=globnat:indeck* sim.exe @@file
 
       self.parser.set_defaults(disableJobMonitoring=False)
       self.parser.add_option("--disableJobMonitoring",action="store_true",dest="disableJobMonitoring",
-                                                   help=SUPPRESS_HELP)
+                                                      help=SUPPRESS_HELP)
       self.parser.add_option("--harvestPath",action="store",type="string",dest="harvestPath",
                                              help=SUPPRESS_HELP)
       self.parser.set_defaults(harvestId=ZERO)
       self.parser.add_option("--harvest",action="store",type="longPositive",dest="harvestId",
-                                        help=SUPPRESS_HELP)
+                                         help=SUPPRESS_HELP)
+
+      self.parser.add_option("--measurementsPath",action="store",type="string",dest="measurementsPath",
+                                                  help=SUPPRESS_HELP)
+
+      self.parser.set_defaults(asynchronous=False)
+      self.parser.add_option("--asynchronous",action="store_true",dest="asynchronous",
+                                              help="Asynchronous simulation - results will not be returned")
 
       self.parser.set_defaults(version=False)
       self.parser.set_defaults(versionClient=False)
@@ -1070,6 +1077,7 @@ submit -p @@file=globnat:indeck* sim.exe @@file
    OPERATIONMODERUNCACHEMISS       = 1 << 24
    OPERATIONMODERUNCACHEPUBLISH    = 1 << 25
    OPERATIONMODERUNHARVESTID       = 1 << 26
+   OPERATIONMODERUNMEASUREMENT     = 1 << 27
 
 
    def getOperationMode(self):
@@ -1110,6 +1118,8 @@ submit -p @@file=globnat:indeck* sim.exe @@file
             operationMode = operationMode | self.OPERATIONMODERUNCACHEPUBLISH
          elif self.getOption('harvestId') != ZERO:
             operationMode = operationMode | self.OPERATIONMODERUNHARVESTID
+         elif self.getOption('measurementsPath'):
+            operationMode = operationMode | self.OPERATIONMODERUNMEASUREMENT
          else:
             if   operationMode & (self.OPERATIONMODEHELPTOOLS | self.OPERATIONMODEHELPVENUES | \
                                   self.OPERATIONMODEHELPMANAGERS | self.OPERATIONMODEVERSIONDISTRIBUTOR):
@@ -1148,6 +1158,14 @@ submit -p @@file=globnat:indeck* sim.exe @@file
             errorMessage = "Run harvesting cannot be detached"
             self.logger.log(logging.ERROR,getLogMessage(errorMessage))
             validArguments = False
+         if self.getOption('measurementsPath'):
+            errorMessage = "Measurement cannot be detached"
+            self.logger.log(logging.ERROR,getLogMessage(errorMessage))
+            validArguments = False
+         if self.getOption('asynchronous'):
+            errorMessage = "Asynchronous cannot be detached"
+            self.logger.log(logging.ERROR,getLogMessage(errorMessage))
+            validArguments = False
 
       if self.getOption('attachId'):
          if self.getOption('localExecution'):
@@ -1166,6 +1184,14 @@ submit -p @@file=globnat:indeck* sim.exe @@file
             errorMessage = "Run harvesting cannot be combined with attach"
             self.logger.log(logging.ERROR,getLogMessage(errorMessage))
             validArguments = False
+         if self.getOption('measurementsPath'):
+            errorMessage = "Measurement cannot be combined with attach"
+            self.logger.log(logging.ERROR,getLogMessage(errorMessage))
+            validArguments = False
+         if self.getOption('asynchronous'):
+            errorMessage = "Asynchronous cannot be combined with attach"
+            self.logger.log(logging.ERROR,getLogMessage(errorMessage))
+            validArguments = False
 
       if self.getOption('cacheHit') or self.getOption('cacheMiss') or self.getOption('cachePublish'):
          squidPattern = re.compile("[a-z0-9_\-]+/[0-9]+/[a-z0-9]{40}\Z")
@@ -1202,6 +1228,14 @@ submit -p @@file=globnat:indeck* sim.exe @@file
             errorMessage = "Run harvesting cannot be combined with cache"
             self.logger.log(logging.ERROR,getLogMessage(errorMessage))
             validArguments = False
+         if self.getOption('measurementsPath'):
+            errorMessage = "Measurement cannot be combined with cache"
+            self.logger.log(logging.ERROR,getLogMessage(errorMessage))
+            validArguments = False
+         if self.getOption('asynchronous'):
+            errorMessage = "Asynchronous cannot be combined with cache"
+            self.logger.log(logging.ERROR,getLogMessage(errorMessage))
+            validArguments = False
 
       if self.getOption('disableJobMonitoring'):
          if self.getOption('localExecution'):
@@ -1220,6 +1254,14 @@ submit -p @@file=globnat:indeck* sim.exe @@file
             errorMessage = "Run harvesting cannot be combined with disableJobMonitoring"
             self.logger.log(logging.ERROR,getLogMessage(errorMessage))
             validArguments = False
+         if self.getOption('measurementsPath'):
+            errorMessage = "Run harvesting cannot be combined with disableJobMonitoring"
+            self.logger.log(logging.ERROR,getLogMessage(errorMessage))
+            validArguments = False
+         if self.getOption('asynchronous'):
+            errorMessage = "Run harvesting cannot be combined with asynchronous"
+            self.logger.log(logging.ERROR,getLogMessage(errorMessage))
+            validArguments = False
 
       if self.getOption('help') or self.getOption('helpTools') or \
          self.getOption('helpVenues') or self.getOption('helpManagers') or self.getOption('helpExamples'):
@@ -1239,6 +1281,14 @@ submit -p @@file=globnat:indeck* sim.exe @@file
             errorMessage = "Help cannot be combined with the harvest option"
             self.logger.log(logging.ERROR,getLogMessage(errorMessage))
             validArguments = False
+         if self.getOption('measurementsPath'):
+            errorMessage = "Help cannot be combined with the measurement option"
+            self.logger.log(logging.ERROR,getLogMessage(errorMessage))
+            validArguments = False
+         if self.getOption('asynchronous'):
+            errorMessage = "Help cannot be combined with the asynchronous option"
+            self.logger.log(logging.ERROR,getLogMessage(errorMessage))
+            validArguments = False
 
       if self.getOption('version') or self.getOption('versionClient') or \
          self.getOption('versionServer') or self.getOption('versionDistributor'):
@@ -1258,6 +1308,14 @@ submit -p @@file=globnat:indeck* sim.exe @@file
             errorMessage = "version cannot be combined with the harvest option"
             self.logger.log(logging.ERROR,getLogMessage(errorMessage))
             validArguments = False
+         if self.getOption('measurementsPath'):
+            errorMessage = "version cannot be combined with the measurement option"
+            self.logger.log(logging.ERROR,getLogMessage(errorMessage))
+            validArguments = False
+         if self.getOption('asynchronous'):
+            errorMessage = "version cannot be combined with the asynchronous option"
+            self.logger.log(logging.ERROR,getLogMessage(errorMessage))
+            validArguments = False
 
       if self.getOption('runName'):
          runName = self.getOption('runName')
@@ -1282,15 +1340,39 @@ submit -p @@file=globnat:indeck* sim.exe @@file
          self.logger.log(logging.ERROR,getLogMessage(errorMessage))
          validArguments = False
       elif self.getOption('statusIds') != None and self.getOption('statusVenues') != None:
-         errorMessage = "Run status reporting cannot be combined venue status reporting"
+         errorMessage = "Run status reporting cannot be combined with venue status reporting"
          self.logger.log(logging.ERROR,getLogMessage(errorMessage))
          validArguments = False
       elif self.getOption('killIds') != None and self.getOption('statusVenues') != None:
-         errorMessage = "Run termination cannot be combined venue status reporting"
+         errorMessage = "Run termination cannot be combined with venue status reporting"
          self.logger.log(logging.ERROR,getLogMessage(errorMessage))
          validArguments = False
       elif self.getOption('harvestId') and self.getOption('statusVenues') != None:
-         errorMessage = "Run harvesting cannot be combined venue status reporting"
+         errorMessage = "Run harvesting cannot be combined with venue status reporting"
+         self.logger.log(logging.ERROR,getLogMessage(errorMessage))
+         validArguments = False
+      elif self.getOption('measurementsPath') and self.getOption('statusVenues') != None:
+         errorMessage = "Measurement cannot be combined with venue status reporting"
+         self.logger.log(logging.ERROR,getLogMessage(errorMessage))
+         validArguments = False
+      elif self.getOption('asynchronous') and self.getOption('statusVenues') != None:
+         errorMessage = "Asynchronous cannot be combined with venue status reporting"
+         self.logger.log(logging.ERROR,getLogMessage(errorMessage))
+         validArguments = False
+      elif self.getOption('killIds') != None and self.getOption('measurementsPath'):
+         errorMessage = "Run termination cannot be combined with measurement"
+         self.logger.log(logging.ERROR,getLogMessage(errorMessage))
+         validArguments = False
+      elif self.getOption('killIds') != None and self.getOption('asynchronous'):
+         errorMessage = "Run termination cannot be combined with asynchronous"
+         self.logger.log(logging.ERROR,getLogMessage(errorMessage))
+         validArguments = False
+      elif self.getOption('statusIds') != None and self.getOption('measurementsPath'):
+         errorMessage = "Run status reporting cannot be combined with measurement"
+         self.logger.log(logging.ERROR,getLogMessage(errorMessage))
+         validArguments = False
+      elif self.getOption('statusIds') != None and self.getOption('asynchronous'):
+         errorMessage = "Run status reporting cannot be combined with asynchronous"
          self.logger.log(logging.ERROR,getLogMessage(errorMessage))
          validArguments = False
       elif len(self.commandArguments) > 0:
@@ -1323,11 +1405,19 @@ submit -p @@file=globnat:indeck* sim.exe @@file
             errorMessage = "harvest cannot be combined with run submission"
             self.logger.log(logging.ERROR,getLogMessage(errorMessage))
             validArguments = False
+         if self.getOption('measurementsPath'):
+            errorMessage = "Measurement cannot be combined with run submission"
+            self.logger.log(logging.ERROR,getLogMessage(errorMessage))
+            validArguments = False
       else:
          if self.getOption('disableJobMonitoring'):
             errorMessage = "disableJobMonitoring requires remote execution"
             self.logger.log(logging.ERROR,getLogMessage(errorMessage))
             validArguments = False
+         if self.getOption('asynchronous'):
+            errorMessage = "asynchronous requires remote execution"
+            self.logger.log(logging.ERROR,getLogMessage(errorMessage))
+            validArguments = False
 
       return(validArguments)
 
